==> dtk6declarative-debug-6.0.19-1-x86_64.pkg.tar.zst: usr/src/debug/dtk6declarative/dtk6declarative/qt6/src/.qt/rcc/qrc_qmake_org_deepin_dtk.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.8.0
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x3,0xbe,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x15,0xc,0xa5,0x1d,0x0,0x86,0x5f,0x57,0x22,0x20,0x71,0xda,
  0x6,0xe3,0x91,0xb0,0xdc,0x52,0xec,0xdf,0xb5,0x79,0x36,0xb1,0x9b,0x86,0xbb,0x8d,
  0x4c,0xb5,0x1f,0xcc,0x9f,0xc2,0xd4,0x34,0x9,0x18,0x90,0x80,0x51,0x59,0x22,0x51,
  0x0,0x4d,0x0,0x4c,0x0,0xda,0x96,0xd5,0x4,0x1d,0x93,0xcb,0xad,0x5b,0x70,0xc5,
  0x86,0xa5,0x1,0xe0,0x8,0x68,0x34,0xa6,0x3,0x7,0xf1,0xbd,0x59,0x1e,0x8f,0x87,
  0xe2,0x7d,0x10,0x34,0xf8,0x16,0xe7,0xb5,0xb0,0x7c,0x2e,0x1c,0x3,0x6b,0xa1,0xf8,
  0x55,0xe9,0x87,0x8a,0x8a,0xe7,0x94,0xb1,0x45,0x51,0xb5,0x5c,0xc7,0xc0,0x3e,0xbe,
  0x44,0x4f,0x8d,0xbe,0xe2,0xeb,0x89,0x62,0x2e,0x93,0x4e,0xe,0xc5,0xf5,0x27,0x87,
  0xe2,0x6d,0x3c,0x5b,0xda,0x27,0x4a,0xaf,0x9b,0x3e,0xf2,0xe7,0x4e,0x63,0x83,0x40,
  0x90,0x95,0x57,0xe8,0xb6,0x12,0xc8,0x6a,0xcb,0x9,0x94,0x4d,0x8a,0x6a,0xf3,0xd0,
  0xe0,0x98,0x67,0x23,0xf6,0x3d,0xa8,0x90,0x74,0xe7,0xd5,0x3c,0x11,0xf2,0x13,0x2f,
  0x93,0xb1,0xc,0x6b,0x68,0x95,0x8f,0x22,0x77,0x25,0x92,0xde,0xf3,0x2c,0x7a,0x84,
  0x2e,0x5a,0x50,0x8a,0x7d,0x9b,0x8,0x19,0xcb,0xe8,0x76,0x37,0x26,0xf1,0x52,0x18,
  0xbb,0x87,0x14,0x37,0x58,0xc9,0xf3,0x4c,0x7a,0xa,0xfc,0x84,0xe9,0xa0,0x46,0xca,
  0xda,0x96,0x49,0xd1,0x39,0x93,0x32,0x97,0xd1,0x71,0xa2,0x19,0x36,0x50,0x96,0x39,
  0x1d,0x85,0x7c,0xeb,0xcd,0xf3,0x5e,0xb8,0x3a,0xc6,0x1e,0x41,0x98,0x6b,0xf1,0xf6,
  0x21,0x4c,0xba,0x90,0xf2,0x88,0x70,0x67,0x48,0x67,0xfc,0x7a,0xf,0xb8,0x1a,0xd6,
  0x14,0x23,0xec,0x59,0xe9,0x86,0x82,0x12,0xcd,0xcf,0x73,0x1a,0xbe,0x6c,0x1,0xcb,
  0x92,0xcf,0x85,0x83,0x9f,0x72,0x9d,0xa3,0xe3,0x77,0x7a,0x4a,0x97,0x3c,0x48,0xdf,
  0x2e,0xde,0x54,0xce,0xc0,0xd8,0x59,0x2d,0x57,0xd8,0x4,0xdd,0xd5,0x9f,0xe3,0xc5,
  0x74,0x49,0xdb,0x56,0x2e,0x7f,0xca,0xf1,0x97,0xe4,0x1a,0x1d,0x37,0xe3,0x2b,0x5e,
  0x5e,0x72,0x5f,0x69,0x23,0xfc,0x4e,0x44,0x68,0x5e,0x7d,0x42,0xd6,0xcd,0x41,0x60,
  0x62,0xf5,0x19,0x9b,0xa0,0x3b,0x7d,0xea,0x19,0x81,0x3d,0xa8,0xc1,0xca,0x8,0x8d,
  0x48,0x92,0xa4,0x90,0x36,0x3,0x31,0x8,0xc2,0x90,0x25,0x63,0xa4,0x1e,0x31,0xc,
  0xa,0x22,0x5,0x91,0x35,0x44,0x9a,0x24,0x1d,0xa7,0x32,0x85,0x71,0x58,0xa8,0xec,
  0x2e,0x4a,0x78,0x24,0xc0,0x1a,0x69,0xd7,0xe3,0x3e,0xd,0x4e,0xe4,0xde,0xa0,0x5a,
  0xb6,0x77,0x8e,0x5c,0xc4,0xe7,0x7d,0x41,0x41,0x2a,0x22,0x38,0x9,0x5b,0xb1,0x3e,
  0xa0,0xb8,0xc7,0x8c,0x1c,0xf4,0x21,0x67,0x9c,0xd,0x4f,0x5a,0xbf,0xd7,0x50,0x11,
  0x82,0x84,0xcb,0xf8,0x4,0x8b,0xab,0x5c,0x94,0x61,0x2e,0xea,0x14,0xea,0x81,0x23,
  0xae,0x18,0xcb,0x6b,0x55,0xa2,0x43,0x71,0x82,0x1b,0x97,0xf4,0x13,0x2a,0x45,0x5e,
  0xfb,0x71,0xad,0x13,0xac,0x2e,0xc5,0xfa,0xba,0xc,0x1f,0xbc,0x4b,0xc3,0xfc,0x86,
  0x8e,0xe7,0x68,0xf2,0xe4,0xf3,0xa9,0x6b,0xd7,0xf4,0xae,0xc6,0xac,0xce,0xfc,0x4f,
  0x17,0xf1,0x89,0xe1,0x9e,0x82,0x52,0x98,0x67,0xd9,0xcb,0x73,0xf8,0xca,0x1,0x45,
  0x25,0xca,0x4c,0x27,0x1b,0x13,0xcb,0xfe,0x73,0xf2,0x3c,0xae,0x21,0x6,0x12,0xc2,
  0xae,0xaf,0xcd,0x71,0xb2,0xaf,0xf8,0x10,0x10,0x56,0xee,0xaf,0xff,0xc2,0xea,0xc2,
  0xbd,0x98,0xf3,0x5b,0xd5,0x9f,0x4c,0x85,0x6c,0xc3,0xe8,0x67,0x7f,0x2d,0xbf,0xa3,
  0xf0,0x7a,0x2c,0x56,0x79,0xda,0xa,0xde,0x60,0x24,0xd9,0xd,0x43,0x45,0x16,0x43,
  0xd8,0x88,0xed,0xf4,0xe,0x9,0xc,0xf2,0x11,0xe1,0xa3,0x60,0xc9,0x54,0x19,0x4,
  0xb0,0x76,0xfd,0x6b,0x59,0x85,0xb1,0x9d,0xe0,0x23,0xb6,0xfd,0x53,0x96,0x13,0x38,
  0x1f,0xad,0x9c,0x2c,0xfe,0x38,0x86,0xbb,0x2,0xc0,0xae,0xf4,0xdf,0x9e,0x73,0xd5,
  0xb3,0x8d,0x3c,0x4,0x26,0x34,0xe8,0x31,0x2c,0xb,0x17,0x23,0x19,0x39,0xdf,0xc4,
  0x51,0x23,0x20,0x64,0xe0,0x1c,0xd,0x84,0x83,0x0,0x12,0xf2,0x71,0xa9,0x7e,0x4f,
  0xb3,0xd0,0x4a,0xec,0x24,0xc1,0xb3,0xe,0x6e,0x8d,0x91,0xe9,0xf4,0x6f,0x44,0x7f,
  0xe3,0xf7,0xa4,0xc9,0x82,0xbb,0x4e,0x76,0x9f,0xc5,0xd5,0x27,0x9e,0x5a,0x3c,0x79,
  0xa5,0x65,0xbe,0x5,0xaa,0x8e,0x55,0x26,0x6b,0xf0,0x58,0x53,0x40,0xa8,0xc1,0xc1,
  0x5a,0xad,0xda,0x43,0xd,0xe9,0x9,0xb1,0x32,0x95,0x51,0xf9,0x10,0x98,0x2e,0x9e,
  0xf,0x4e,0xc8,0x27,0x53,0x8a,0xe3,0xd8,0xf7,0x66,0xe4,0xfb,0xcc,0x1,0xcc,0xdb,
  0xce,0x1a,0xc3,0xf9,0x62,0xa1,0x6b,0x31,0xac,0xaf,0xa4,0xdc,0xbf,0x76,0x90,0xd,
  0xfe,0x82,0x16,0x48,0x1a,0x5,0x58,0x7d,0xb5,0xdf,0xf1,0x5a,0x47,0x35,0x4e,0xb5,
  0x69,0x68,0xc4,0xc,0x5f,0x37,0x67,0x96,0x38,0x66,0xa0,0x9d,0x3,0xb5,0xe5,0x5a,
  0xd,0x27,0x14,0x15,0x9f,0x42,0x28,0x21,0x20,0xbc,0xff,0x0,0xe6,0x11,0xcd,0xdd,
  0x28,0x8c,0x37,0xb0,0x22,0xb8,0xc0,0xde,0x8b,0x56,0x86,0x8c,0x71,0x30,0x12,0x7,
  0x75,0xd0,0x8a,0xf3,0xdb,0x7f,0x46,0x4d,0x4f,0x88,0x4f,0xbd,0x0,0x6a,0xab,0xeb,
  0xfd,0xee,0x4a,0xff,0x15,0xf4,0x92,0x47,0xaa,0xf5,0xe5,0x7f,0x29,0x1b,0xb7,0x86,
  0xe8,0x3,0x6,0x42,0x25,0xd2,0xe1,0xc5,0xfb,0x42,0x6a,0x7c,0x10,0x6b,0xcd,0xc2,
  0xc2,0x18,0x55,0x33,0x8c,0x11,0x85,0x5f,0x8e,0x7b,0xeb,0xf2,0xf3,0xa3,0x41,0xe,
  0x85,0x48,0x52,0xe4,0xa9,0x58,0x9f,0x70,0x23,0xed,0x73,0x44,0x96,0x30,0x8d,0x14,
  0x9,0x85,0x66,0x79,0x9,0x53,0xb6,0x1a,0xbc,0x3b,0x4c,0xf1,0x56,0x5f,0xd0,0xa5,
  0x87,0x1f,0xcb,0x87,0x23,0xbd,0xbc,0x7,0xd3,0x72,0xc0,0x91,0xc4,0x32,0x39,0x40,
  0xe,0x33,0xb6,0x33,0xd6,0xcf,0x5d,0xe9,0x56,0x23,0x0,0x5c,0x5,
  
};

static const unsigned char qt_resource_name[] = {
  // org
  0x0,0x3,
  0x0,0x0,0x76,0x87,
  0x0,0x6f,
  0x0,0x72,0x0,0x67,
    // deepin
  0x0,0x6,
  0x6,0xab,0xc6,0xfe,
  0x0,0x64,
  0x0,0x65,0x0,0x65,0x0,0x70,0x0,0x69,0x0,0x6e,
    // dtk
  0x0,0x3,
  0x0,0x0,0x6b,0xab,
  0x0,0x64,
  0x0,0x74,0x0,0x6b,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x92,0xac,0x2f,0xf0,0xe0,
  // :/org
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x92,0xac,0x2f,0xf0,0xe0,
  // :/org/deepin
  0x0,0x0,0x0,0xc,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x92,0xac,0x2f,0xf0,0xe0,
  // :/org/deepin/dtk
  0x0,0x0,0x0,0x1e,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x92,0xac,0x2f,0xf0,0xe0,
  // :/org/deepin/dtk/qmldir
  0x0,0x0,0x0,0x2a,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x92,0xac,0x2f,0xf0,0xe0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_deepin_dtk)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_deepin_dtk)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_deepin_dtk)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_deepin_dtk)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_deepin_dtk)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_deepin_dtk)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif

==> dtk6declarative-debug-6.0.19-2-x86_64.pkg.tar.zst: usr/src/debug/dtk6declarative/dtk6declarative/qt6/src/.qt/rcc/qrc_qmake_org_deepin_dtk.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.8.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x3,0xbe,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x15,0xc,0xa5,0x1d,0x0,0x86,0x5f,0x57,0x22,0x20,0x71,0xda,
  0x6,0xe3,0x91,0xb0,0xdc,0x52,0xec,0xdf,0xb5,0x79,0x36,0xb1,0x9b,0x86,0xbb,0x8d,
  0x4c,0xb5,0x1f,0xcc,0x9f,0xc2,0xd4,0x34,0x9,0x18,0x90,0x80,0x51,0x59,0x22,0x51,
  0x0,0x4d,0x0,0x4c,0x0,0xda,0x96,0xd5,0x4,0x1d,0x93,0xcb,0xad,0x5b,0x70,0xc5,
  0x86,0xa5,0x1,0xe0,0x8,0x68,0x34,0xa6,0x3,0x7,0xf1,0xbd,0x59,0x1e,0x8f,0x87,
  0xe2,0x7d,0x10,0x34,0xf8,0x16,0xe7,0xb5,0xb0,0x7c,0x2e,0x1c,0x3,0x6b,0xa1,0xf8,
  0x55,0xe9,0x87,0x8a,0x8a,0xe7,0x94,0xb1,0x45,0x51,0xb5,0x5c,0xc7,0xc0,0x3e,0xbe,
  0x44,0x4f,0x8d,0xbe,0xe2,0xeb,0x89,0x62,0x2e,0x93,0x4e,0xe,0xc5,0xf5,0x27,0x87,
  0xe2,0x6d,0x3c,0x5b,0xda,0x27,0x4a,0xaf,0x9b,0x3e,0xf2,0xe7,0x4e,0x63,0x83,0x40,
  0x90,0x95,0x57,0xe8,0xb6,0x12,0xc8,0x6a,0xcb,0x9,0x94,0x4d,0x8a,0x6a,0xf3,0xd0,
  0xe0,0x98,0x67,0x23,0xf6,0x3d,0xa8,0x90,0x74,0xe7,0xd5,0x3c,0x11,0xf2,0x13,0x2f,
  0x93,0xb1,0xc,0x6b,0x68,0x95,0x8f,0x22,0x77,0x25,0x92,0xde,0xf3,0x2c,0x7a,0x84,
  0x2e,0x5a,0x50,0x8a,0x7d,0x9b,0x8,0x19,0xcb,0xe8,0x76,0x37,0x26,0xf1,0x52,0x18,
  0xbb,0x87,0x14,0x37,0x58,0xc9,0xf3,0x4c,0x7a,0xa,0xfc,0x84,0xe9,0xa0,0x46,0xca,
  0xda,0x96,0x49,0xd1,0x39,0x93,0x32,0x97,0xd1,0x71,0xa2,0x19,0x36,0x50,0x96,0x39,
  0x1d,0x85,0x7c,0xeb,0xcd,0xf3,0x5e,0xb8,0x3a,0xc6,0x1e,0x41,0x98,0x6b,0xf1,0xf6,
  0x21,0x4c,0xba,0x90,0xf2,0x88,0x70,0x67,0x48,0x67,0xfc,0x7a,0xf,0xb8,0x1a,0xd6,
  0x14,0x23,0xec,0x59,0xe9,0x86,0x82,0x12,0xcd,0xcf,0x73,0x1a,0xbe,0x6c,0x1,0xcb,
  0x92,0xcf,0x85,0x83,0x9f,0x72,0x9d,0xa3,0xe3,0x77,0x7a,0x4a,0x97,0x3c,0x48,0xdf,
  0x2e,0xde,0x54,0xce,0xc0,0xd8,0x59,0x2d,0x57,0xd8,0x4,0xdd,0xd5,0x9f,0xe3,0xc5,
  0x74,0x49,0xdb,0x56,0x2e,0x7f,0xca,0xf1,0x97,0xe4,0x1a,0x1d,0x37,0xe3,0x2b,0x5e,
  0x5e,0x72,0x5f,0x69,0x23,0xfc,0x4e,0x44,0x68,0x5e,0x7d,0x42,0xd6,0xcd,0x41,0x60,
  0x62,0xf5,0x19,0x9b,0xa0,0x3b,0x7d,0xea,0x19,0x81,0x3d,0xa8,0xc1,0xca,0x8,0x8d,
  0x48,0x92,0xa4,0x90,0x36,0x3,0x31,0x8,0xc2,0x90,0x25,0x63,0xa4,0x1e,0x31,0xc,
  0xa,0x22,0x5,0x91,0x35,0x44,0x9a,0x24,0x1d,0xa7,0x32,0x85,0x71,0x58,0xa8,0xec,
  0x2e,0x4a,0x78,0x24,0xc0,0x1a,0x69,0xd7,0xe3,0x3e,0xd,0x4e,0xe4,0xde,0xa0,0x5a,
  0xb6,0x77,0x8e,0x5c,0xc4,0xe7,0x7d,0x41,0x41,0x2a,0x22,0x38,0x9,0x5b,0xb1,0x3e,
  0xa0,0xb8,0xc7,0x8c,0x1c,0xf4,0x21,0x67,0x9c,0xd,0x4f,0x5a,0xbf,0xd7,0x50,0x11,
  0x82,0x84,0xcb,0xf8,0x4,0x8b,0xab,0x5c,0x94,0x61,0x2e,0xea,0x14,0xea,0x81,0x23,
  0xae,0x18,0xcb,0x6b,0x55,0xa2,0x43,0x71,0x82,0x1b,0x97,0xf4,0x13,0x2a,0x45,0x5e,
  0xfb,0x71,0xad,0x13,0xac,0x2e,0xc5,0xfa,0xba,0xc,0x1f,0xbc,0x4b,0xc3,0xfc,0x86,
  0x8e,0xe7,0x68,0xf2,0xe4,0xf3,0xa9,0x6b,0xd7,0xf4,0xae,0xc6,0xac,0xce,0xfc,0x4f,
  0x17,0xf1,0x89,0xe1,0x9e,0x82,0x52,0x98,0x67,0xd9,0xcb,0x73,0xf8,0xca,0x1,0x45,
  0x25,0xca,0x4c,0x27,0x1b,0x13,0xcb,0xfe,0x73,0xf2,0x3c,0xae,0x21,0x6,0x12,0xc2,
  0xae,0xaf,0xcd,0x71,0xb2,0xaf,0xf8,0x10,0x10,0x56,0xee,0xaf,0xff,0xc2,0xea,0xc2,
  0xbd,0x98,0xf3,0x5b,0xd5,0x9f,0x4c,0x85,0x6c,0xc3,0xe8,0x67,0x7f,0x2d,0xbf,0xa3,
  0xf0,0x7a,0x2c,0x56,0x79,0xda,0xa,0xde,0x60,0x24,0xd9,0xd,0x43,0x45,0x16,0x43,
  0xd8,0x88,0xed,0xf4,0xe,0x9,0xc,0xf2,0x11,0xe1,0xa3,0x60,0xc9,0x54,0x19,0x4,
  0xb0,0x76,0xfd,0x6b,0x59,0x85,0xb1,0x9d,0xe0,0x23,0xb6,0xfd,0x53,0x96,0x13,0x38,
  0x1f,0xad,0x9c,0x2c,0xfe,0x38,0x86,0xbb,0x2,0xc0,0xae,0xf4,0xdf,0x9e,0x73,0xd5,
  0xb3,0x8d,0x3c,0x4,0x26,0x34,0xe8,0x31,0x2c,0xb,0x17,0x23,0x19,0x39,0xdf,0xc4,
  0x51,0x23,0x20,0x64,0xe0,0x1c,0xd,0x84,0x83,0x0,0x12,0xf2,0x71,0xa9,0x7e,0x4f,
  0xb3,0xd0,0x4a,0xec,0x24,0xc1,0xb3,0xe,0x6e,0x8d,0x91,0xe9,0xf4,0x6f,0x44,0x7f,
  0xe3,0xf7,0xa4,0xc9,0x82,0xbb,0x4e,0x76,0x9f,0xc5,0xd5,0x27,0x9e,0x5a,0x3c,0x79,
  0xa5,0x65,0xbe,0x5,0xaa,0x8e,0x55,0x26,0x6b,0xf0,0x58,0x53,0x40,0xa8,0xc1,0xc1,
  0x5a,0xad,0xda,0x43,0xd,0xe9,0x9,0xb1,0x32,0x95,0x51,0xf9,0x10,0x98,0x2e,0x9e,
  0xf,0x4e,0xc8,0x27,0x53,0x8a,0xe3,0xd8,0xf7,0x66,0xe4,0xfb,0xcc,0x1,0xcc,0xdb,
  0xce,0x1a,0xc3,0xf9,0x62,0xa1,0x6b,0x31,0xac,0xaf,0xa4,0xdc,0xbf,0x76,0x90,0xd,
  0xfe,0x82,0x16,0x48,0x1a,0x5,0x58,0x7d,0xb5,0xdf,0xf1,0x5a,0x47,0x35,0x4e,0xb5,
  0x69,0x68,0xc4,0xc,0x5f,0x37,0x67,0x96,0x38,0x66,0xa0,0x9d,0x3,0xb5,0xe5,0x5a,
  0xd,0x27,0x14,0x15,0x9f,0x42,0x28,0x21,0x20,0xbc,0xff,0x0,0xe6,0x11,0xcd,0xdd,
  0x28,0x8c,0x37,0xb0,0x22,0xb8,0xc0,0xde,0x8b,0x56,0x86,0x8c,0x71,0x30,0x12,0x7,
  0x75,0xd0,0x8a,0xf3,0xdb,0x7f,0x46,0x4d,0x4f,0x88,0x4f,0xbd,0x0,0x6a,0xab,0xeb,
  0xfd,0xee,0x4a,0xff,0x15,0xf4,0x92,0x47,0xaa,0xf5,0xe5,0x7f,0x29,0x1b,0xb7,0x86,
  0xe8,0x3,0x6,0x42,0x25,0xd2,0xe1,0xc5,0xfb,0x42,0x6a,0x7c,0x10,0x6b,0xcd,0xc2,
  0xc2,0x18,0x55,0x33,0x8c,0x11,0x85,0x5f,0x8e,0x7b,0xeb,0xf2,0xf3,0xa3,0x41,0xe,
  0x85,0x48,0x52,0xe4,0xa9,0x58,0x9f,0x70,0x23,0xed,0x73,0x44,0x96,0x30,0x8d,0x14,
  0x9,0x85,0x66,0x79,0x9,0x53,0xb6,0x1a,0xbc,0x3b,0x4c,0xf1,0x56,0x5f,0xd0,0xa5,
  0x87,0x1f,0xcb,0x87,0x23,0xbd,0xbc,0x7,0xd3,0x72,0xc0,0x91,0xc4,0x32,0x39,0x40,
  0xe,0x33,0xb6,0x33,0xd6,0xcf,0x5d,0xe9,0x56,0x23,0x0,0x5c,0x5,
  
};

static const unsigned char qt_resource_name[] = {
  // org
  0x0,0x3,
  0x0,0x0,0x76,0x87,
  0x0,0x6f,
  0x0,0x72,0x0,0x67,
    // deepin
  0x0,0x6,
  0x6,0xab,0xc6,0xfe,
  0x0,0x64,
  0x0,0x65,0x0,0x65,0x0,0x70,0x0,0x69,0x0,0x6e,
    // dtk
  0x0,0x3,
  0x0,0x0,0x6b,0xab,
  0x0,0x64,
  0x0,0x74,0x0,0x6b,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x93,0x88,0x79,0x9a,0x38,
  // :/org
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x93,0x88,0x79,0x9a,0x38,
  // :/org/deepin
  0x0,0x0,0x0,0xc,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x93,0x88,0x79,0x9a,0x38,
  // :/org/deepin/dtk
  0x0,0x0,0x0,0x1e,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x93,0x88,0x79,0x9a,0x38,
  // :/org/deepin/dtk/qmldir
  0x0,0x0,0x0,0x2a,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x93,0x88,0x79,0x9a,0x38,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_deepin_dtk)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_deepin_dtk)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_deepin_dtk)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_deepin_dtk)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_deepin_dtk)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_deepin_dtk)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
